@@ -20,7 +20,7 @@ class ContainerVersionBehavior:
 
     self.click_ctx      = click.get_current_context()
     parent_command      = self.click_ctx.parent.command.name
-    self.container_type = parent_command.split("-")[0]
+    self.container_type = parent_command.replace('-version', '')
 
     self.container           = kwargs.get('container')
     self.port                = kwargs.get('port')
