@@ -19,6 +19,10 @@ cli.add_command(commands.profile)
 cli.add_command(commands.organization)
 cli.add_command(commands.widget)
 cli.add_command(commands.widget_version)
+cli.add_command(commands.app_builder)
+cli.add_command(commands.app_builder_version)
+cli.add_command(commands.asset)
+cli.add_command(commands.asset_version)
 cli.add_command(commands.component_set)
 cli.add_command(commands.component_set_version)
 cli.add_command(commands.microservice)
