@@ -4,6 +4,10 @@ from .organization import *
 from .env import *
 from .widget import *
 from .widget_version import *
+from .app_builder import *
+from .app_builder_version import *
+from .asset import *
+from .asset_version import *
 from .profile import *
 from .microservice import *
 from .microservice_version import *
